##  Creating IT Component Fact Sheets Manually
You can create a fact sheet in the inventory by filling out the fact sheet creation form. As you enter the name of the fact sheet, the system provides matching recommendations from the reference catalog. You can use these recommendations to create the fact sheet with enesssential information pre-filled from the catalog.
When you create the fact sheet from the recommendation:
  * The fact sheet is then linked to the reference catalog item, ensuring it stays updated as the catalog data evolves.
  * The fact sheet is also linked to the associated provider and technology category fact sheets, if you have configured the reference catalog that way.


The fact creation form also shows you matching fact sheets that already exist in your inventory, helping you avoid creating duplicates. For a detailed guide on creating a fact sheet, see [Creating a Fact Sheet in the Inventory](https://help.sap.com/docs/leanix/ea/creating-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759925e7a441014a7e9e6f502b4cd21__creating_a_fact_sheet_in_the_inventory).
![Creating an IT Component Fact Sheet Manually](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioc4fe6386336a4301a9d953cac3ba288b_LowRes.png)
Creating an IT Component Fact Sheet Manually
